@@ -1,13 +1,16 @@
 package Business::ID::NPWP;
 
-our $DATE = '2019-11-21'; # DATE
-our $VERSION = '0.090'; # VERSION
-
 use 5.010001;
 use warnings;
 use strict;
 
 use Exporter 'import';
+
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2024-01-10'; # DATE
+our $DIST = 'Business-ID-NPWP'; # DIST
+our $VERSION = '0.091'; # VERSION
+
 our @EXPORT_OK = qw(parse_npwp);
 
 our %SPEC;
@@ -24,6 +27,22 @@ $SPEC{parse_npwp} = {
             pos => 0,
             req => 1,
         },
+        allow_nik => {
+            schema => 'bool*',
+            description => <<'MARKDOWN',
+
+Based on PMK 112 Tahun 2022, Indonesian citizenship registration number (NIK -
+nomor induk kependudukan) is also allowed as NPWP. NIK has 16 digits, while the
+traditional NPWP is 15 digits. A prefix 0 will be added later so all NPWP will
+be 16 digits in the future.
+
+By default, NPWP is allowed to have 16 digits but the first digit must be 0. If
+this setting is set to true, NPWP with the first digit other than 0 is also
+allowed but will be checked for NIK validness.
+
+MARKDOWN
+            default => 0,
+        },
     },
 };
 sub parse_npwp {
@@ -39,7 +58,22 @@ sub parse_npwp {
     $npwp =~ s/\D+//g;
     # assume BBB = 000 if not specified
     if (length($npwp) == 12) { $npwp .= "000" }
-    return [400, "Not 15 digit"] unless length($npwp) == 15;
+
+    if (length $npwp == 16) {
+        if ($npwp =~ s/\A0//) {
+            # will be checked as traditional NPWP
+        } elsif ($args{allow_nik}) {
+            require Business::ID::NIK;
+            my $nik_res = Business::ID::NIK::parse_nik(nik => $npwp);
+            return $nik_res unless $nik_res->[0] == 200;
+            $nik_res->[2]{is_nik} = 1;
+            return $nik_res;
+        } else {
+            return [400, "For 16-digit NPWP, the first digit must be 0"];
+        }
+    } elsif (length $npwp != 15) {
+        return [400, "Must be 15 or 16 digit"];
+    }
 
     $npwp =~ /^(.)(.)(.)(.)(.)(.)(.)(.)(.)/;
     if ((_z(1*$1) + _z(2*$2) + _z(1*$3) +
@@ -81,7 +115,7 @@ Business::ID::NPWP - Parse Indonesian taxpayer registration number (NPWP)
 
 =head1 VERSION
 
-This document describes version 0.090 of Business::ID::NPWP (from Perl distribution Business-ID-NPWP), released on 2019-11-21.
+This document describes version 0.091 of Business::ID::NPWP (from Perl distribution Business-ID-NPWP), released on 2024-01-10.
 
 =head1 SYNOPSIS
 
@@ -127,7 +161,7 @@ each branch.
 
 Usage:
 
- parse_npwp(%args) -> [status, msg, payload, meta]
+ parse_npwp(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Parse Indonesian taxpayer registration number (NPWP).
 
@@ -137,20 +171,32 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
+=item * B<allow_nik> => I<bool> (default: 0)
+
+Based on PMK 112 Tahun 2022, Indonesian citizenship registration number (NIK -
+nomor induk kependudukan) is also allowed as NPWP. NIK has 16 digits, while the
+traditional NPWP is 15 digits. A prefix 0 will be added later so all NPWP will
+be 16 digits in the future.
+
+By default, NPWP is allowed to have 16 digits but the first digit must be 0. If
+this setting is set to true, NPWP with the first digit other than 0 is also
+allowed but will be checked for NIK validness.
+
 =item * B<npwp>* => I<str>
 
 Input NPWP to be parsed.
 
+
 =back
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -162,6 +208,51 @@ Please visit the project's homepage at L<https://metacpan.org/release/Business-I
 
 Source repository is at L<https://github.com/perlancar/perl-Business-ID-NPWP>.
 
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 CONTRIBUTORS
+
+=for stopwords Steven Haryanto
+
+=over 4
+
+=item *
+
+Steven Haryanto <stevenharyanto@gmail.com>
+
+=item *
+
+Steven Haryanto <steven@masterweb.net>
+
+=back
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2024, 2019, 2015, 2014, 2013 by perlancar <perlancar@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Business-ID-NPWP>
@@ -170,15 +261,4 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2019, 2015, 2014, 2013 by perlancar@cpan.org.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
